<?php declare(strict_types=1);

namespace App\Controller;

use App\Entity\CameraType;
use App\Form\CameraTypeType;
use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\HttpFoundation\Request;

/**
 * Cameratype controller.
 *
 * @Route("camera-type")
 */
class CameraTypeController extends Controller
{
	use FormControllerTrait;

	protected const ENTITY = CameraType::class;
	protected const FORM = CameraTypeType::class;

	/**
	 * Lists all cameraType entities.
	 *
	 * @Route("/", name="camera-type_index", methods={"GET"})
	 */
	public function indexAction()
	{
		return $this->itemListView('cameratype/index.html.twig', 'cameraTypes', [
			'type' => 'ASC',
		]);
	}

	/**
	 * Creates a new cameraType entity.
	 *
	 * @Route("/new", name="camera-type_new", methods={"GET", "POST"})
	 */
	public function newAction(Request $request)
	{
		return $this->itemCreate($request, 'cameratype/new.html.twig', 'cameraType', 'camera-type_show');
	}

	/**
	 * Finds and displays a cameraType entity.
	 *
	 * @Route("/{id}", name="camera-type_show", methods={"GET"})
	 */
	public function showAction(CameraType $cameraType)
	{
		return $this->itemView($cameraType, 'cameratype/show.html.twig', 'cameraType');
	}

	/**
	 * Displays a form to edit an existing cameraType entity.
	 *
	 * @Route("/{id}/edit", name="camera-type_edit", methods={"GET", "POST"})
	 */
	public function editAction(Request $request, CameraType $cameraType)
	{
		return $this->itemUpdate($request, $cameraType, 'cameratype/edit.html.twig', 'cameraType', 'camera-type_show');
	}

	/**
	 * Deletes a cameraType entity.
	 *
	 * @Route("/{id}", name="camera-type_delete", methods={"DELETE"})
	 */
	public function deleteAction(Request $request, CameraType $cameraType)
	{
		return $this->itemDelete($request, $cameraType, 'camera-type_index');
	}

	/**
	 * Creates a form to delete a cameraType entity.
	 *
	 * @param CameraType $cameraType The cameraType entity
	 *
	 * @return \Symfony\Component\Form\Form The form
	 */
	private function createDeleteForm(CameraType $cameraType)
	{
		return $this->buildForm($cameraType, 'camera-type_delete', 'DELETE');
	}
}
